@@ -4,7 +4,7 @@ function(YA, bw1, Ynm, y.lbl, digits.d, brief,
          clpct, tvalue, pvalue, ub, lb,
          show.title, pdf.file, pdf.width, pdf.height) {
 
-  dYA <- density(YA, bw1)
+  suppressWarnings(dYA <- density(YA, bw1))
 
   if (!brief) {
     cat("\n\n------ Graphics Smoothing Parameter ------\n\n")
@@ -13,7 +13,6 @@ function(YA, bw1, Ynm, y.lbl, digits.d, brief,
   }
 
 
-
   cat("--------------------------------------------------\n")
 
   # values needed for graph
